==> igniteui-react-charts-16.4.1.tgz: package/ES5/AreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { IUnknownValuePlotting_$type } from "igniteui-react-core/ES5/IUnknownValuePlotting";
import { CategoryLineRasterizer } from "./CategoryLineRasterizer";
import { UnknownValuePlotting_$type } from "igniteui-react-core/ES5/UnknownValuePlotting";
import { DependencyProperty } from "igniteui-react-core/ES5/DependencyProperty";
import { Type, typeCast, runOn, enumGetBox, markType } from "igniteui-react-core/ES5/type";
import { Path } from "igniteui-react-core/ES5/Path";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-react-core/ES5/PropertyMetadata";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { ISortingAxis_$type } from "./ISortingAxis";
import { Color } from "igniteui-react-core/ES5/Color";
var AreaSeries = /** @class */ (function (_super) {
    tslib_1.__extends(AreaSeries, _super);
    function AreaSeries() {
        var _this = _super.call(this) || this;
        _this.p8 = null;
        _this.p8 = new CategoryLineRasterizer();
        _this.ab = AreaSeries.$;
        _this.pr = 0;
        return _this;
    }
    AreaSeries.prototype.bf = function () {
        return new AreaSeriesView(this);
    };
    AreaSeries.prototype.m7 = function () {
        return 1;
    };
    AreaSeries.prototype.il = function (a) {
        _super.prototype.il.call(this, a);
        this.p7 = a;
    };
    AreaSeries.prototype.get_ck = function () {
        return true;
    };
    Object.defineProperty(AreaSeries.prototype, "ck", {
        get: function () {
            return this.get_ck();
        },
        enumerable: true,
        configurable: true
    });
    AreaSeries.prototype.preferredCategoryMode = function (a) {
        return this.pr;
    };
    AreaSeries.prototype.df = function (a, b) {
        var c = this.lc(this.lf(a), true, false);
        if (this.py(a, c, b)) {
            return true;
        }
        if (this.de(a, b)) {
            return true;
        }
        if (this.lv(a, b)) {
            return true;
        }
        return false;
    };
    AreaSeries.prototype.ho = function (a, b) {
        _super.prototype.ho.call(this, a, b);
        var c = b;
        c.c5();
    };
    AreaSeries.prototype.oe = function (a, b) {
        var _this = this;
        _super.prototype.oe.call(this, a, b);
        var c = b.cl.d;
        var d = typeCast(AreaSeriesView.$, b);
        var e = a.f;
        var f = this.getEffectiveViewport1(d);
        this.m5.x(this, this.nq(), this.po, runOn(this, this.mr), this.ny(b), this.nz(b));
        var g = false;
        var h = this.m5.c;
        if (h != null) {
            g = true;
        }
        if (g) {
            var i = new ScalerParams(0, b.bq, b.bp, this.po.b8, f);
            this.oa(e, -1, this.valueColumn.count, this.po, i, b.n);
        }
        var j = d.dc;
        var k = d.dd;
        var l = d.df;
        var m = d.dh;
        this.m5.ae(j, true, false, true, true);
        this.m5.ae(k, true, false, true, true);
        this.m5.ae(l, false, true, false, false);
        this.m5.ae(m, false, true, false, false);
        if (b.cp(a)) {
            d.c7(e.count, e, true, c, this.eq, function (n, o, p, q, r) { return _this.o8(n, a.f.count, b); }, this.unknownValuePlotting, e.count == 1 ? null : this.on(e, e.count - 1, b.bp, b.bq, true));
            b.cs(a);
        }
        var n = this.fetchYAxis();
        l._opacity = this.m5.i * this.d2;
        m._opacity = 0.5 * this.m5.i * this.d2;
    };
    AreaSeries.prototype.ir = function (a, b, c, d) {
        _super.prototype.ir.call(this, a, b, c, d);
        switch (b) {
            case AreaSeries.$$p[0]:
                this.m2.m = this.unknownValuePlotting == 0;
                this.i4(false);
                this.ib();
                break;
        }
    };
    Object.defineProperty(AreaSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.nt;
        },
        enumerable: true,
        configurable: true
    });
    AreaSeries.$t = markType(AreaSeries, 'AreaSeries', HorizontalAnchoredCategorySeries.$, [IUnknownValuePlotting_$type]);
    return AreaSeries;
}(HorizontalAnchoredCategorySeries));
export { AreaSeries };
Type.dep(DependencyProperty, PropertyMetadata, AreaSeries, 'raisePropertyChanged', ['UnknownValuePlotting::qa', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
var AreaSeriesView = /** @class */ (function (_super) {
    tslib_1.__extends(AreaSeriesView, _super);
    function AreaSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c4 = null;
        _this.de = new Path();
        _this.di = new Path();
        _this.dg = new Path();
        _this.dj = new Path();
        _this.c8 = new Path();
        _this.da = new Path();
        _this.c9 = new Path();
        _this.db = new Path();
        _this.c4 = a;
        return _this;
    }
    AreaSeriesView.prototype.ap = function () {
        _super.prototype.ap.call(this);
        if (!this.n) {
            this.e.bj = 1;
        }
    };
    Object.defineProperty(AreaSeriesView.prototype, "dc", {
        get: function () {
            return this.di;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AreaSeriesView.prototype, "dd", {
        get: function () {
            return this.dj;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AreaSeriesView.prototype, "df", {
        get: function () {
            return this.de;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AreaSeriesView.prototype, "dh", {
        get: function () {
            return this.dg;
        },
        enumerable: true,
        configurable: true
    });
    AreaSeriesView.prototype.c5 = function () {
        this.de.aj = null;
        this.dg.aj = null;
        this.di.aj = null;
        this.dj.aj = null;
        this.an();
    };
    AreaSeriesView.prototype.c6 = function (a, b, c, d, e, f, g) {
        this.c7(a, b, c, d, e, f, g, null);
    };
    AreaSeriesView.prototype.c7 = function (a, b, c, d, e, f, g, h) {
        this.c4.p8.a = typeCast(ISortingAxis_$type, this.cn.fetchXAxis()) !== null ? true : false;
        this.c4.p8.j(this.de, this.di, this.dg, this.dj, a, b, c, d, e, f, g, h);
        this.an();
    };
    AreaSeriesView.prototype.a9 = function () {
        _super.prototype.a9.call(this);
        this.c8.aj = this.de.aj;
        this.da.aj = this.di.aj;
        this.c9.aj = this.dg.aj;
        this.db.aj = this.dj.aj;
        var a = this.bk();
        this.c8._fill = a;
        this.c8._opacity = 1;
        this.c9._fill = a;
        this.c9._opacity = 1;
        this.da._stroke = a;
        this.da.ac = this.e.eu + 3;
        this.db._stroke = a;
        this.db.ac = this.e.eu + 3;
    };
    AreaSeriesView.prototype.a3 = function (a, b) {
        _super.prototype.a3.call(this, a, b);
        if (b) {
            a.s(this.c8);
            a.s(this.c9);
            a.s(this.da);
            a.s(this.db);
        }
        else {
            a.s(this.de);
            a.s(this.dg);
            a.s(this.di);
            a.s(this.dj);
        }
    };
    AreaSeriesView.prototype.ai = function (a) {
        _super.prototype.ai.call(this, a);
        this.e.a2.exportPathData(a, this.di, "lowerShape", ["Lower"]);
        this.e.a2.exportPathData(a, this.dj, "upperShape", ["Upper", "Main"]);
        this.e.a2.exportPathData(a, this.dg, "translucentShape", ["Translucent"]);
        this.e.a2.exportPathData(a, this.de, "fillShape", ["Fill"]);
    };
    AreaSeriesView.prototype.ac = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.k1 = a;
        this.e.er = 5;
        this.e.es = 1;
        this.e.et = -3;
    };
    AreaSeriesView.$t = markType(AreaSeriesView, 'AreaSeriesView', AnchoredCategorySeriesView.$);
    return AreaSeriesView;
}(AnchoredCategorySeriesView));
export { AreaSeriesView };
/*<BeginStatics Name="Infragistics.Controls.Charts.AreaSeries" />*/
/*<EndStatics Name="Infragistics.Controls.Charts.AreaSeries" />*/

==> igniteui-react-charts-16.6.4.tgz: package/ES5/AreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { IUnknownValuePlotting_$type } from "igniteui-react-core/ES5/IUnknownValuePlotting";
import { CategoryLineRasterizer } from "./CategoryLineRasterizer";
import { UnknownValuePlotting_$type } from "igniteui-react-core/ES5/UnknownValuePlotting";
import { DependencyProperty } from "igniteui-react-core/ES5/DependencyProperty";
import { Type, typeCast, runOn, enumGetBox, markType } from "igniteui-react-core/ES5/type";
import { Path } from "igniteui-react-core/ES5/Path";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-react-core/ES5/PropertyMetadata";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { ISortingAxis_$type } from "./ISortingAxis";
import { Color } from "igniteui-react-core/ES5/Color";
var AreaSeries = /** @class */ (function (_super) {
    tslib_1.__extends(AreaSeries, _super);
    function AreaSeries() {
        var _this = _super.call(this) || this;
        _this.p9 = null;
        _this.p9 = new CategoryLineRasterizer();
        _this.ab = AreaSeries.$;
        _this.ps = 0;
        return _this;
    }
    AreaSeries.prototype.bf = function () {
        return new AreaSeriesView(this);
    };
    AreaSeries.prototype.m7 = function () {
        return 1;
    };
    AreaSeries.prototype.il = function (a) {
        _super.prototype.il.call(this, a);
        this.p8 = a;
    };
    AreaSeries.prototype.get_ck = function () {
        return true;
    };
    AreaSeries.prototype.preferredCategoryMode = function (a) {
        return this.ps;
    };
    AreaSeries.prototype.df = function (a, b) {
        var c = this.lc(this.lf(a), true, false);
        if (this.pz(a, c, b)) {
            return true;
        }
        if (this.de(a, b)) {
            return true;
        }
        if (this.lv(a, b)) {
            return true;
        }
        return false;
    };
    AreaSeries.prototype.ho = function (a, b) {
        _super.prototype.ho.call(this, a, b);
        var c = b;
        c.c7();
    };
    AreaSeries.prototype.of = function (a, b) {
        var _this = this;
        _super.prototype.of.call(this, a, b);
        var c = b.cn.d;
        var d = typeCast(AreaSeriesView.$, b);
        var e = a.f;
        var f = this.getEffectiveViewport1(d);
        this.m5.x(this, this.nq(), this.pp, runOn(this, this.mr), this.ny(b), this.nz(b));
        var g = false;
        var h = this.m5.c;
        if (h != null) {
            g = true;
        }
        if (g) {
            var i = new ScalerParams(0, b.bs, b.br, this.pp.b8, f);
            this.ob(e, -1, this.valueColumn.count, this.pp, i, b.n);
        }
        var j = d.de;
        var k = d.df;
        var l = d.dh;
        var m = d.dj;
        this.m5.ae(j, true, false, true, true);
        this.m5.ae(k, true, false, true, true);
        this.m5.ae(l, false, true, false, false);
        this.m5.ae(m, false, true, false, false);
        if (b.cr(a)) {
            d.c9(e.count, e, true, c, this.eq, function (n, o, p, q, r) { return _this.o9(n, a.f.count, b); }, this.unknownValuePlotting, e.count == 1 ? null : this.oo(e, e.count - 1, b.br, b.bs, true));
            b.cu(a);
        }
        var n = this.fetchYAxis();
        l._opacity = this.m5.i * this.d2;
        m._opacity = 0.5 * this.m5.i * this.d2;
    };
    AreaSeries.prototype.ir = function (a, b, c, d) {
        _super.prototype.ir.call(this, a, b, c, d);
        switch (b) {
            case AreaSeries.$$p[0]:
                this.m2.m = this.unknownValuePlotting == 0;
                this.i4(false);
                this.ib();
                break;
        }
    };
    Object.defineProperty(AreaSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.nt;
        },
        enumerable: true,
        configurable: true
    });
    AreaSeries.$t = markType(AreaSeries, 'AreaSeries', HorizontalAnchoredCategorySeries.$, [IUnknownValuePlotting_$type]);
    return AreaSeries;
}(HorizontalAnchoredCategorySeries));
export { AreaSeries };
Type.dep(DependencyProperty, PropertyMetadata, AreaSeries, 'raisePropertyChanged', ['UnknownValuePlotting::qb', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
var AreaSeriesView = /** @class */ (function (_super) {
    tslib_1.__extends(AreaSeriesView, _super);
    function AreaSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c6 = null;
        _this.dg = new Path();
        _this.dk = new Path();
        _this.di = new Path();
        _this.dl = new Path();
        _this.da = new Path();
        _this.dc = new Path();
        _this.db = new Path();
        _this.dd = new Path();
        _this.c6 = a;
        return _this;
    }
    AreaSeriesView.prototype.ap = function () {
        _super.prototype.ap.call(this);
        if (!this.n) {
            this.e.bj = 1;
        }
    };
    Object.defineProperty(AreaSeriesView.prototype, "de", {
        get: function () {
            return this.dk;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AreaSeriesView.prototype, "df", {
        get: function () {
            return this.dl;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AreaSeriesView.prototype, "dh", {
        get: function () {
            return this.dg;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AreaSeriesView.prototype, "dj", {
        get: function () {
            return this.di;
        },
        enumerable: true,
        configurable: true
    });
    AreaSeriesView.prototype.c7 = function () {
        this.dg.aj = null;
        this.di.aj = null;
        this.dk.aj = null;
        this.dl.aj = null;
        this.an();
    };
    AreaSeriesView.prototype.c8 = function (a, b, c, d, e, f, g) {
        this.c9(a, b, c, d, e, f, g, null);
    };
    AreaSeriesView.prototype.c9 = function (a, b, c, d, e, f, g, h) {
        this.c6.p9.a = typeCast(ISortingAxis_$type, this.cp.fetchXAxis()) !== null ? true : false;
        this.c6.p9.j(this.dg, this.dk, this.di, this.dl, a, b, c, d, e, f, g, h);
        this.an();
    };
    AreaSeriesView.prototype.a9 = function () {
        _super.prototype.a9.call(this);
        this.da.aj = this.dg.aj;
        this.dc.aj = this.dk.aj;
        this.db.aj = this.di.aj;
        this.dd.aj = this.dl.aj;
        var a = this.bl();
        this.da._fill = a;
        this.da._opacity = 1;
        this.db._fill = a;
        this.db._opacity = 1;
        this.dc._stroke = a;
        this.dc.ac = this.e.eu + 3;
        this.dd._stroke = a;
        this.dd.ac = this.e.eu + 3;
    };
    AreaSeriesView.prototype.a3 = function (a, b) {
        _super.prototype.a3.call(this, a, b);
        if (b) {
            a.s(this.da);
            a.s(this.db);
            a.s(this.dc);
            a.s(this.dd);
        }
        else {
            a.s(this.dg);
            a.s(this.di);
            a.s(this.dk);
            a.s(this.dl);
        }
    };
    AreaSeriesView.prototype.ai = function (a) {
        _super.prototype.ai.call(this, a);
        this.e.a2.exportPathData(a, this.dk, "lowerShape", ["Lower"]);
        this.e.a2.exportPathData(a, this.dl, "upperShape", ["Upper", "Main"]);
        this.e.a2.exportPathData(a, this.di, "translucentShape", ["Translucent"]);
        this.e.a2.exportPathData(a, this.dg, "fillShape", ["Fill"]);
    };
    AreaSeriesView.prototype.ac = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.k1 = a;
        this.e.er = 5;
        this.e.es = 1;
        this.e.et = -3;
    };
    AreaSeriesView.$t = markType(AreaSeriesView, 'AreaSeriesView', AnchoredCategorySeriesView.$);
    return AreaSeriesView;
}(AnchoredCategorySeriesView));
export { AreaSeriesView };
